from typing import Any, Dict

def multi_file_load_config(*filenames: str) -> Dict[str, Any]: ...
def load_config(config_filename: str) -> Dict[str, Any]: ...
def raw_config_parse(config_filename: str, parse_subsections: bool = ...) -> Dict[str, Any]: ...
def build_profile_map(parsed_ini_config: Dict[str, Any]) -> Dict[str, Any]: ...
